Glossary
- Changelog
- The Changelog is a file in the repository (
CHANGELOG.md) that contains the Release Notes for every release of that repository. Usually, new releases are added at the top of the file. - Conventional Commits
- Conventional Commits is a specification for commit messages. It is the only supported commit message schema in
releaser-pleaser. Follow the link to learn more. - Forge
- A forge is a web-based collaborative software platform for both developing and sharing computer applications.1
- Markdown
-
Markdown is a lightweight markup language used on many forges as the preferred way to format text.
In
releaser-pleaserMarkdown is used for most texts. - Pre-release
-
Pre-releases are a concept of SemVer. They follow the normal versioning schema but use a suffix out of
-alpha.X,-beta.Xand-rc.X.Pre-releases are not considered “stable” and are usually not recommended for most users.
Learn more in the Pre-releases guide.
- Release Pull Request
-
A Release Pull Request is opened by
releaser-pleaserwhenever it finds releasable commits in your project. It proposes a new version number and the Changelog. Once it is merged,releaser-pleasercreates a matching release.Learn more in the Release Pull Request explanation.
- Release Notes
-
Release Notes describe the changes made to the repository since the last release. They are made available in the Changelog, in Git Tags and through the forge-native Releases.
Learn more in the Release Notes customization guide.
- Semantic Versioning (SemVer)
-
Semantic Versioning is a specification for version numbers. It is the only supported versioning schema in
releaser-pleaser. Follow the link to learn more. - Updater
-
Updaters can update or create files that will be included in Release Pull Request. Examples of Updaters are
changelogforCHANGELOG.md,genericthat can update arbitrary files andpackagejsonthat knows how to update Node.JSpackage.jsonfiles.
-
Quote from Wikipedia “Forge (software)” ↩